end_of_values

Function end_of_values 

fn end_of_values<'a>(input: &mut Input<'a>) -> PResult<'a, ()>
Recognizes the end of a list of values, without consuming anything.

A list of values ends at a blank line, at the next section header or at the end of the file.