RawBackupEntry

Struct RawBackupEntry 

struct RawBackupEntry {
    pub path: RelativeFilePath,
    pub md5: Option<Md5Checksum>,
}
A path that should be tracked for backup together with its checksum.

Fields

path: RelativeFilePath

The path to the file that is backed up.

md5: Option<Md5Checksum>

The optional MD5 checksum of the backed up file as stored in the package.