fn try_values_from<'a, T>(
layer: &str,
) -> impl Parser<Input<'a>, Vec<T>, ErrMode<ParseStack<'a>>>Expand description
A parser helper for multi-value types, which returns a FromStr-style parser for types that
don’t implement their own parser.
Parses a list of values, where each value is in its own line.
Repeats until a blank line, the next section header (%...%) or the end of the file.
The line ending of the last value is not consumed.
Errors
Returns an error if a value cannot be parsed into T or if the
section layout does not match expectations.