struct RawBackupEntry {
pub path: RelativeFilePath,
pub md5: Option<Md5Checksum>,
}Expand description
A path that should be tracked for backup together with its checksum.
Fields
path: RelativeFilePathThe path to the file that is backed up.
md5: Option<Md5Checksum>The optional MD5 checksum of the backed up file as stored in the package.